==> haskell-jwt-0.7.2-11-i686.pkg.tar.xz: usr/share/haskell/register/haskell-jwt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: jwt
version: 0.7.2
id: jwt-0.7.2-3YtiLaCTsql5dSxOuuvhfN
key: jwt-0.7.2-3YtiLaCTsql5dSxOuuvhfN
license: MIT
maintainer: stefan@saasen.me
homepage: https://bitbucket.org/ssaasen/haskell-jwt
synopsis: JSON Web Token (JWT) decoding and encoding
description:
    JSON Web Token (JWT) is a compact URL-safe means of representing claims to be transferred between two parties.
    .
    To get started, see the documentation for the "Web.JWT" module.
category: Web
author: Stefan Saasen
exposed: True
indefinite: False
exposed-modules:
    Web.JWT
hidden-modules: Data.Text.Extended Data.ByteString.Extended
abi: 5dd005d5a4d1def9504058a45dc4f4a8
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/jwt-0.7.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/jwt-0.7.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/jwt-0.7.2
hs-libraries: HSjwt-0.7.2-3YtiLaCTsql5dSxOuuvhfN
depends:
    base-4.10.0.0 cryptonite-0.24-JQ3NPvIvMVWG9FHR2Q0Evi
    memory-0.14.8-HEYe2msABjoBOvbV0yaOyF bytestring-0.10.8.2
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y containers-0.5.10.2
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q
    data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J
    http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW time-1.8.0.2
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP
    network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             cryptonite-0.24-JQ3NPvIvMVWG9FHR2Q0Evi=1928ece35e67ec41b499da4f70bba50f
             memory-0.14.8-HEYe2msABjoBOvbV0yaOyF=4c821a304108f2b075d812c81435d53c
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=1bd098f0c2fb1217cc4d33a7e7a9941a
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q=a0445f54fa186d288e1223c9f60f5307
             data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J=066f8e1a5e7dca2a5fd62aefb939793f
             http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW=dac2e6d9eb3caedd3c76c9c39d0f2e0c
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP=aad58cc65045b8e62f1806217258d930
             network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK=dcf3b42c1c39d8e42cbbbf74ea3e6c8c
haddock-interfaces: /usr/share/doc/haskell-jwt/html/jwt.haddock
haddock-html: /usr/share/doc/haskell-jwt/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-jwt-0.7.2-12-i686.pkg.tar.xz: usr/share/haskell/register/haskell-jwt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: jwt
version: 0.7.2
id: jwt-0.7.2-3RkfL0EcJ6zHq4EbeAdasN
key: jwt-0.7.2-3RkfL0EcJ6zHq4EbeAdasN
license: MIT
maintainer: stefan@saasen.me
homepage: https://bitbucket.org/ssaasen/haskell-jwt
synopsis: JSON Web Token (JWT) decoding and encoding
description:
    JSON Web Token (JWT) is a compact URL-safe means of representing claims to be transferred between two parties.
    .
    To get started, see the documentation for the "Web.JWT" module.
category: Web
author: Stefan Saasen
exposed: True
indefinite: False
exposed-modules:
    Web.JWT
hidden-modules: Data.Text.Extended Data.ByteString.Extended
abi: 20ce79864477c9080b360ba7bd77c816
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/jwt-0.7.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/jwt-0.7.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/jwt-0.7.2
hs-libraries: HSjwt-0.7.2-3RkfL0EcJ6zHq4EbeAdasN
depends:
    base-4.10.0.0 cryptonite-0.24-6xc03vLJCgFIcBUj8mCBYP
    memory-0.14.8-KR3LQmPtL0V2hu8SCUEPxQ bytestring-0.10.8.2
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y containers-0.5.10.2
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q
    data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J
    http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW time-1.8.0.2
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP
    network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             cryptonite-0.24-6xc03vLJCgFIcBUj8mCBYP=302f7d9b300167b44be1bfa67778ed25
             memory-0.14.8-KR3LQmPtL0V2hu8SCUEPxQ=66cafb37fc02a74908fd731801b55463
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=1bd098f0c2fb1217cc4d33a7e7a9941a
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q=a0445f54fa186d288e1223c9f60f5307
             data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J=066f8e1a5e7dca2a5fd62aefb939793f
             http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW=dac2e6d9eb3caedd3c76c9c39d0f2e0c
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP=aad58cc65045b8e62f1806217258d930
             network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK=dcf3b42c1c39d8e42cbbbf74ea3e6c8c
haddock-interfaces: /usr/share/doc/haskell-jwt/html/jwt.haddock
haddock-html: /usr/share/doc/haskell-jwt/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
